==> haskell-aeson-diff-1.1.0.5-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-diff
version: 1.1.0.5
id: aeson-diff-1.1.0.5-GwTJuNizv1zINqKRBxkHMG
key: aeson-diff-1.1.0.5-GwTJuNizv1zINqKRBxkHMG
license: BSD-3-Clause
copyright: (c) 2015 Thomas Sutton and others.
maintainer: me@thomas-sutton.id.au
author: Thomas Sutton
homepage: https://github.com/thsutton/aeson-diff
synopsis: Extract and apply patches to JSON documents.
description:
    .
    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.
    .
category: JSON, Web, Algorithms
abi: 18ae7533d644de8d42e72c2aab5238fb
exposed: True
exposed-modules:
    Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-diff-1.1.0.5
library-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-diff-1.1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/aeson-diff-1.1.0.5
hs-libraries: HSaeson-diff-1.1.0.5-GwTJuNizv1zINqKRBxkHMG
depends:
    aeson-1.4.2.0-3p7goNB3q4s1JbMrIJBuLL base-4.12.0.0
    bytestring-0.10.8.2
    edit-distance-vector-1.0.0.4-5QalLWx3XsH57Wk3J1CdcP
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo mtl-2.2.2
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR text-1.2.3.1
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html: /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-diff-1.1.0.5-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-diff
version: 1.1.0.5
id: aeson-diff-1.1.0.5-2JWZMNGW4ssHeg1udEwfti
key: aeson-diff-1.1.0.5-2JWZMNGW4ssHeg1udEwfti
license: BSD-3-Clause
copyright: (c) 2015 Thomas Sutton and others.
maintainer: me@thomas-sutton.id.au
author: Thomas Sutton
homepage: https://github.com/thsutton/aeson-diff
synopsis: Extract and apply patches to JSON documents.
description:
    .
    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.
    .
category: JSON, Web, Algorithms
abi: bde830e32ba877fe85fe09de9a206002
exposed: True
exposed-modules:
    Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-diff-1.1.0.5
library-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-diff-1.1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/aeson-diff-1.1.0.5
hs-libraries: HSaeson-diff-1.1.0.5-2JWZMNGW4ssHeg1udEwfti
depends:
    aeson-1.4.2.0-Avxlg2iWl9mA2BcbnSAv1Y base-4.12.0.0
    bytestring-0.10.8.2
    edit-distance-vector-1.0.0.4-5QalLWx3XsH57Wk3J1CdcP
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo mtl-2.2.2
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR text-1.2.3.1
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html: /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
